@@ -82,7 +82,8 @@ default_stan_control <- function(prior, adapt_delta = NULL,
                           "R2" = 0.99,
                           "hs" = 0.99,
                           "hs_plus" = 0.99,
-                          # "t" = if (any(prior$df <= 2)) 0.99 else 0.95,
+                          "lasso" = 0.99,
+                          "product_normal" = 0.99,
                           0.95) # default
   }
   nlist(adapt_delta, max_treedepth)
@@ -110,6 +111,7 @@ is.gamma <- function(x) x == "Gamma"
 is.ig <- function(x) x == "inverse.gaussian"
 is.nb <- function(x) x == "neg_binomial_2"
 is.poisson <- function(x) x == "poisson"
+is.beta <- function(x) x == "beta"
 
 # Test for a given estimation method
 #
@@ -296,10 +298,13 @@ validate_glm_formula <- function(f) {
 # @return If no constant variables are found mf is returned, otherwise an error
 #   is thrown.
 check_constant_vars <- function(mf) {
+  # don't check if columns are constant for binomial
+  mf1 <- if (NCOL(mf[, 1]) == 2) mf[, -1, drop=FALSE] else mf
+  
   lu <- function(x) length(unique(x))
   nocheck <- c("(weights)", "(offset)", "(Intercept)")
-  sel <- !colnames(mf) %in% nocheck
-  is_constant <- apply(mf[, sel, drop = FALSE], 2, lu) == 1
+  sel <- !colnames(mf1) %in% nocheck
+  is_constant <- apply(mf1[, sel, drop=FALSE], 2, lu) == 1
   if (any(is_constant)) 
     stop("Constant variable(s) found: ", 
          paste(names(is_constant)[is_constant], collapse = ", "), 
@@ -456,15 +461,15 @@ validate_parameter_value <- function(x) {
 #
 # @param scale Value of scale parameter (can be NULL).
 # @param default Default value to use if \code{scale} is NULL.
-# @param link String naming the link function.
+# @param link String naming the link function or NULL.
 # @return If a probit link is being used, \code{scale} (or \code{default} if
 #   \code{scale} is NULL) is scaled by \code{dnorm(0) / dlogis(0)}. Otherwise
 #   either \code{scale} or \code{default} is returned.
 set_prior_scale <- function(scale, default, link) {
-  stopifnot(is.numeric(default), is.character(link))
+  stopifnot(is.numeric(default), is.character(link) || is.null(link))
   if (is.null(scale)) 
     scale <- default
-  if (link == "probit")
+  if (isTRUE(link == "probit"))
     scale <- scale * dnorm(0) / dlogis(0)
   
   return(scale)
@@ -526,6 +531,10 @@ get_x.default <- function(object) {
   object[["x"]] %ORifNULL% model.matrix(object)
 }
 #' @export
+get_x.gamm4 <- function(object) {
+  object$glmod$raw_X %ORifNULL% stop("X not found")
+}
+#' @export
 get_x.lmerMod <- function(object) {
   object$glmod$X %ORifNULL% stop("X not found")
 }
@@ -641,3 +650,37 @@ model_has_weights <- function(x) {
     TRUE
   }
 }
+
+
+# Validate newdata argument for posterior_predict, log_lik, etc.
+#
+# Doesn't check if the correct variables are included (that's done in pp_data),
+# just that newdata is either NULL or a data frame with no missing values.
+# @param x User's 'newdata' argument
+# @return Either NULL or a data frame
+#
+validate_newdata <- function(x) {
+  if (is.null(x))
+    return(NULL)
+  if (!is.data.frame(x))
+    stop("If 'newdata' is specified it must be a data frame.", call. = FALSE)
+  if (any(is.na(x)))
+    stop("NAs are not allowed in 'newdata'.", call. = FALSE)
+
+  as.data.frame(x)
+}
+
+# Check that a stanfit object (or list returned by rstan::optimizing) is valid
+#
+check_stanfit <- function(x) {
+  if (is.list(x)) {
+    if (!all(c("par", "value") %in% names(x)))
+      stop("Invalid object produced please report bug")
+  }
+  else {
+    stopifnot(is(x, "stanfit"))
+    if (x@mode != 0)
+      stop("Invalid stanfit object produced please report bug")
+  }
+  return(TRUE)
+}
