@@ -17,10 +17,10 @@
 
 #' Posterior distribution of the linear predictor
 #'
-#' Extract the posterior draws of the linear predictor, possibly transformed by
-#' the inverse-link function. This function is occasionally convenient, but it
-#' should be used sparingly. Inference and model checking should generally be
-#' carried out using the posterior predictive distribution (see
+#' Extract the posterior draws of the linear predictor, possibly transformed by 
+#' the inverse-link function. This function is occasionally useful, but it 
+#' should be used sparingly. Inference and model checking should generally be 
+#' carried out using the posterior predictive distribution (i.e., using 
 #' \code{\link{posterior_predict}}).
 #'
 #' @keywords internal
@@ -36,18 +36,19 @@
 #'   design matrix \code{X} (or \code{cbind(X,Z)} for models with group-specific
 #'   terms) constructed from \code{newdata} is returned. The default is 
 #'   \code{FALSE}.
-#' 
+#'   
 #' @return The default is to return a \code{draws} by \code{nrow(newdata)} 
 #'   matrix of simulations from the posterior distribution of the (possibly 
 #'   transformed) linear predictor. The exception is if the argument \code{XZ} 
 #'   is set to \code{TRUE} (see the \code{XZ} argument description above).
-#' 
+#'   
 #' @seealso \code{\link{posterior_predict}} to draw from the posterior 
-#'   predictive distribution of the outcome, which is almost always preferable.
+#'   predictive distribution of the outcome, which is typically preferable.
 #'
 #' @examples
 #' if (!exists("example_model")) example(example_model)
-#'
+#' print(family(example_model))
+#' 
 #' # linear predictor on log-odds scale
 #' linpred <- posterior_linpred(example_model)
 #' # probabilities
@@ -62,33 +63,31 @@ posterior_linpred <- function(object, ...) {
 
 #' @rdname posterior_linpred
 #' @export 
-posterior_linpred.stanreg <- function(object, transform = FALSE, newdata = NULL, 
-                              re.form = NULL, offset = NULL, XZ = FALSE, 
-                              ...) {
-  validate_stanreg_object(object)
-  if (used.optimizing(object))
-    STOP_not_optimizing("posterior_linpred")
-  if (!is.null(newdata)) {
-    if ("gam" %in% names(object))
-      stop("'posterior_linpred' with 'newdata' not yet supported ",
-           "for models estimated via 'stan_gamm4'.")
-    newdata <- as.data.frame(newdata)
-    if (any(is.na(newdata)))
-      stop("Currently NAs are not allowed in 'newdata'.")
+posterior_linpred.stanreg <-
+  function(object,
+           transform = FALSE,
+           newdata = NULL,
+           re.form = NULL,
+           offset = NULL,
+           XZ = FALSE,
+           ...) {
+    if (used.optimizing(object))
+      STOP_not_optimizing("posterior_linpred")
+    
+    newdata <- validate_newdata(newdata)
+    dat <- pp_data(object,
+                   newdata = newdata,
+                   re.form = re.form,
+                   offset = offset)
+    if (XZ) {
+      XZ <- dat[["x"]]
+      if (is.mer(object))
+        XZ <- cbind(XZ, t(dat[["Zt"]]))
+      return(XZ)
+    }
+    eta <- pp_eta(object, data = dat, draws = NULL)[["eta"]]
+    if (!transform)
+      return(eta)
+    
+    linkinv(object)(eta)
   }
-  dat <- pp_data(object,
-                 newdata = newdata,
-                 re.form = re.form,
-                 offset = offset,
-                 ...)
-  if (XZ) {
-    XZ <- dat[["x"]]
-    if (is.mer(object))
-      XZ <- cbind(XZ, t(dat[["Zt"]]))
-    return(XZ)
-  }
-  eta <- pp_eta(object, data = dat, draws = NULL)[["eta"]]
-  if (!transform)
-    return(eta)
-  linkinv(object)(eta)
-}
