@@ -30,13 +30,11 @@
 #' non-informative, giving the same probability mass to implausible values as
 #' plausible ones.
 #' 
-#' @export 
 #' @name priors
-#' @param location Prior location. For \code{normal} and \code{student_t} 
-#'   (provided that \code{df > 1}) this is the prior mean. For \code{cauchy} 
-#'   (which is equivalent to \code{student_t} with \code{df=1}), the mean does 
-#'   not exist and \code{location} is the prior median. The default value is 
-#'   \eqn{0}, except for \code{R2} which has no default value for
+#' @param location Prior location. In most cases, this is the prior mean, but for 
+#'   \code{cauchy} (which is equivalent to \code{student_t} with \code{df=1}), 
+#'   the mean does not exist and \code{location} is the prior median. The default 
+#'   value is \eqn{0}, except for \code{R2} which has no default value for
 #'   \code{location}. For \code{R2}, \code{location} pertains to the prior
 #'   location of the \eqn{R^2} under a Beta distribution, but the interpretation
 #'   of the \code{location} parameter depends on the specified value of the
@@ -45,7 +43,12 @@
 #' @param df,df1,df2 Prior degrees of freedom. The default is \eqn{1} for 
 #'   \code{student_t}, in which case it is equivalent to \code{cauchy}. For the
 #'   hierarchical shrinkage priors (\code{hs} and \code{hs_plus}) the degrees of
-#'   freedom parameter(s) default to \eqn{3}.
+#'   freedom parameter(s) default to \eqn{3}. For the \code{product_normal} prior,
+#'   the degrees of freedom parameter defauls must be an integer (vector) that
+#'   is at least \eqn{2} (the default).
+#' @param global_df,global_scale Optional arguments for the hierarchical
+#'   shrinkage priors. See the \emph{Hierarchical shrinkage family} section
+#'   below.
 #' @param what A character string among \code{'mode'} (the default),
 #'   \code{'mean'}, \code{'median'}, or \code{'log'} indicating how the
 #'   \code{location} parameter is interpreted in the \code{LKJ} case. If
@@ -56,6 +59,18 @@
 #'   or equal to two, the mode of this Beta distribution does not exist
 #'   and an error will prompt the user to specify another choice for
 #'   \code{what}.
+#' @param autoscale A logical scalar, defaulting to \code{TRUE}. If \code{TRUE} 
+#'   then the scales of the priors on the intercept and regression coefficients 
+#'   may be additionally modified internally by \pkg{rstanarm} as follows.
+#'   First, if the \emph{outcome} is Gaussian, the prior scales for the
+#'   intercept and coefficients are multiplied by \code{2*sd(y)}. Additionally,
+#'   if the \code{QR} argument to the model fitting function (e.g.
+#'   \code{stan_glm}) is \code{FALSE} then: for a predictor with only one value
+#'   nothing is changed; for a predictor \code{x} with exactly two unique
+#'   values, we take the user-specified (or default) scale(s) for the selected
+#'   priors and divide by the range of \code{x}; for a predictor \code{x} with
+#'   more than two unique values, we divide the prior scale(s) by
+#'   \code{2*sd(x)}.
 #'   
 #' @details The details depend on the family of the prior being used:
 #' \subsection{Student t family}{
@@ -65,6 +80,7 @@
 #'   \item \code{student_t(df, location, scale)}
 #'   \item \code{cauchy(location, scale)}
 #'   }
+#'   Each of these functions also takes an argument \code{autoscale}.
 #'   
 #'   For the prior distribution for the intercept, \code{location}, 
 #'   \code{scale}, and \code{df} should be scalars. For the prior for the other
@@ -80,16 +96,15 @@
 #'   used, in which case these defaults are scaled by a factor of 
 #'   \code{dnorm(0)/dlogis(0)}, which is roughly 1.6.
 #'   
-#'   If the \code{scaled} argument to \code{prior_options} is \code{TRUE} (the
-#'   default), then the scales will be further adjusted as described above in
-#'   the documentation of the \code{scaled} argument in the \strong{Arguments} 
-#'   section.
+#'   If the \code{autoscale} argument is \code{TRUE} (the default), then the
+#'   scales will be further adjusted as described above in the documentation of
+#'   the \code{autoscale} argument in the \strong{Arguments} section.
 #' }
 #' \subsection{Hierarchical shrinkage family}{
 #'   Family members:
 #'   \itemize{
-#'   \item \code{hs(df)}
-#'   \item \code{hs_plus(df1, df2)}
+#'   \item \code{hs(df, global_df, global_scale)}
+#'   \item \code{hs_plus(df1, df2, global_df, global_scale)}
 #'   }
 #'   
 #'   The hierarchical shrinkage priors are normal with a mean of zero and a 
@@ -99,17 +114,22 @@
 #'   also half Cauchy. This is called the "horseshoe prior". The hierarchical 
 #'   shrinkage (\code{hs}) prior in the \pkg{rstanarm} package instead utilizes 
 #'   a half Student t distribution for the standard deviation (with 3 degrees of
-#'   freedom by default), scaled by a half Cauchy parameter, as described by
-#'   Piironen and Vehtari (2015). It is possible to change the \code{df}
-#'   argument, the prior degrees of freedom, to obtain less or more shrinkage.
+#'   freedom by default), as described by Piironen and Vehtari (2015). It is
+#'   possible to change the \code{df} argument, the prior degrees of freedom, to
+#'   obtain less or more shrinkage. Traditionally the standard deviation
+#'   parameter is then scaled by the square root of a \emph{global} half Cauchy 
+#'   parameter, although \pkg{rstanarm} allows setting \code{global_df} and 
+#'   \code{global_scale} arguments, in which case this global parameter is 
+#'   distributed half Student t with degrees of freedom \code{global_df} and 
+#'   scale \code{global_scale}.
 #'   
 #'   The hierarhical shrinkpage plus (\code{hs_plus}) prior is a normal with a 
 #'   mean of zero and a standard deviation that is distributed as the product of
 #'   two independent half Student t parameters (both with 3 degrees of freedom
-#'   (\code{df1}, \code{df2}) by default) that are each scaled by the same
-#'   square root of a half Cauchy parameter.
+#'   (\code{df1}, \code{df2}) by default) that are each scaled in a similar way
+#'   to the \code{hs} prior.
 #'   
-#'   These hierarchical shrinkage priors have very tall modes and very fat 
+#'   The hierarchical shrinkage priors have very tall modes and very fat 
 #'   tails. Consequently, they tend to produce posterior distributions that are
 #'   very concentrated near zero, unless the predictor has a strong influence on
 #'   the outcome, in which case the prior has little influence. Hierarchical
@@ -119,6 +139,70 @@
 #'   divergent transitions see the Troubleshooting section of the 
 #'   \emph{How to Use the rstanarm Package} vignette.
 #' }
+#' \subsection{Laplace family}{
+#'   Family members:
+#'   \itemize{
+#'   \item \code{laplace(location, scale)}
+#'   \item \code{lasso(df, location, scale)}
+#'   }
+#'   Each of these functions also takes an argument \code{autoscale}.
+#'
+#'   The Laplace distribution is also known as the double-exponential distribution.
+#'   It is a symmetric distribution with a sharp peak at its mean / median / mode
+#'   and fairly long tails. This distribution can be motivated as a scale mixture
+#'   of a normal distribution and the remarks above about the normal distribution
+#'   apply here as well.
+#'   
+#'   The lasso approach to supervised learning can be expressed as finding the
+#'   posterior mode when the likelihood is Gaussian and the priors on the 
+#'   coefficients have independent Laplace distributions. It is commonplace in
+#'   supervised learning to choose the tuning parameter by cross-validation,
+#'   whereas a more Bayesian approach would be to place a prior on \dQuote{it},
+#'   or rather its reciprocal in our case (i.e. \emph{smaller} values correspond
+#'   to more shrinkage toward the prior location vector). We use a chi-square
+#'   prior with degrees of freedom equal to that specified in the call to
+#'   \code{lasso} or, by default, 1. The expectation of a chi-square random
+#'   variable is equal to this degrees of freedom and the mode is equal to the
+#'   degrees of freeom minus 2, if this difference is positive.
+#'   
+#'   It is also common in supervised learning to standardize the predictors 
+#'   before training the model. We do not recommend doing so. Instead, it is
+#'   better to specify \code{autoscale = TRUE} (the default value), which 
+#'   will adjust the scales of the priors according to the dispersion in the
+#'   variables. See the documentation of the \code{autoscale} argument above 
+#'   and also the \code{\link{prior_summary}} page for more information.
+#' }
+#' \subsection{Product-normal family}{
+#'   Family members:
+#'   \itemize{
+#'   \item \code{product_normal(df, location, scale)}
+#'   }
+#'   The product-normal distribution is the product of at least two independent 
+#'   normal variates each with mean zero, shifted by the \code{location} parameter. It 
+#'   can be shown that the density of a product-normal variate is symmetric and 
+#'   infinite at \code{location}, so this prior resembles a \dQuote{spike-and-slab} 
+#'   prior for sufficiently large values of the \code{scale} parameter. For better 
+#'   or for worse, this prior may be appropriate when it is strongly believed (by 
+#'   someone) that a regression coefficient \dQuote{is} equal to the \code{location}, 
+#'   parameter even though no true Bayesian would specify such a prior.
+#'   
+#'   Each element of \code{df} must be an integer of at least \eqn{2} because these 
+#'   \dQuote{degrees of freedom} are interpreted as the number of normal variates being
+#'   multiplied and then shifted by \code{location} to yield the regression coefficient.
+#'   Higher degrees of freedom produce more a sharper spike at \code{location}. 
+#'   
+#'   Each element of \code{scale} must be a non-negative real number that is interpreted
+#'   as the standard deviation of the normal variates being multiplied and then shifted
+#'   by \code{location} to yield the regression coefficient. In other words, the elements
+#'   of \code{scale} may differ, but the k-th standard deviation is presumed to
+#'   hold for all the normal deviates that are multiplied together and shifted by the k-th
+#'   element of \code{location} to yield the k-th regression coefficient. The elements of
+#'   \code{scale} are not the prior standard deviations of the regression coefficients. The
+#'   prior variance of the regression coefficients is equal to the scale raised to the power
+#'   of \eqn{2} times the corresponding element of \code{df}. Thus, larger values of 
+#'   \code{scale} put more prior volume on values of the regression coefficient that are far 
+#'   from zero.
+#' }
 #' \subsection{Dirichlet family}{
 #'   Family members:
 #'   \itemize{
@@ -265,7 +349,8 @@
 #'                            chains = 1, seed = 12345, iter = 500, # for speed only
 #'                            prior = student_t(df = 4, 0, 2.5), 
 #'                            prior_intercept = cauchy(0,10), 
-#'                            prior_ops = prior_options(prior_scale_for_dispersion = 2))
+#'                            prior_aux = exponential(1/2))
+#' plot(prior_pred_fit, "hist")
 #' 
 #' \donttest{
 #' # Can assign priors to names
@@ -273,11 +358,17 @@
 #' fit <- stan_glm(fmla, data = mtcars, prior = N05, prior_intercept = N05)
 #' }
 #' 
-#' # Visually compare normal, student_t, and cauchy
+#' # Visually compare normal, student_t, cauchy, laplace, and product_normal
 #' compare_priors <- function(scale = 1, df_t = 2, xlim = c(-10, 10)) {
 #'   dt_loc_scale <- function(x, df, location, scale) { 
 #'     1/scale * dt((x - location)/scale, df)  
 #'   }
+#'   dlaplace <- function(x, location, scale) {
+#'     0.5 / scale * exp(-abs(x - location) / scale)
+#'   }
+#'   dproduct_normal <- function(x, scale) {
+#'     besselK(abs(x) / scale ^ 2, nu = 0) / (scale ^ 2 * pi)
+#'   }
 #'   stat_dist <- function(dist, ...) {
 #'     ggplot2::stat_function(ggplot2::aes_(color = dist), ...)
 #'   }
@@ -287,9 +378,13 @@
 #'     stat_dist("student_t", size = .75, fun = dt_loc_scale, 
 #'               args = list(df = df_t, location = 0, scale = scale)) +
 #'     stat_dist("cauchy", size = .75, linetype = 2, fun = dcauchy, 
-#'               args = list(location = 0, scale = scale))
+#'               args = list(location = 0, scale = scale)) + 
+#'     stat_dist("laplace", size = .75, linetype = 2, fun = dlaplace,
+#'               args = list(location = 0, scale = scale)) +
+#'     stat_dist("product_normal", size = .75, linetype = 2, fun = dproduct_normal,
+#'               args = list(scale = 1))            
 #' }
-#' # Cauchy has fattest tails, then student_t, then normal
+#' # Cauchy has fattest tails, followed by student_t, laplace, and normal
 #' compare_priors()
 #' 
 #' # The student_t with df = 1 is the same as the cauchy
@@ -303,39 +398,80 @@
 #' # actually saying that a coefficient value of e.g. -500 is quite plausible
 #' compare_priors(scale = 1000, xlim = c(-1000,1000))
 #' 
-normal <- function(location = 0, scale = NULL) {
+NULL
+
+#' @rdname priors
+#' @export
+normal <- function(location = 0, scale = NULL, autoscale = TRUE) {
   validate_parameter_value(scale)
-  nlist(dist = "normal", df = NA, location, scale)
+  nlist(dist = "normal", df = NA, location, scale, autoscale)
 }
 
 #' @rdname priors
 #' @export
-student_t <- function(df = 1, location = 0, scale = NULL) {
+student_t <- function(df = 1, location = 0, scale = NULL, autoscale = TRUE) {
   validate_parameter_value(scale)
   validate_parameter_value(df)
-  nlist(dist = "t", df, location, scale)
+  nlist(dist = "t", df, location, scale, autoscale)
 }
 
 #' @rdname priors
 #' @export
-cauchy <- function(location = 0, scale = NULL) {
-  student_t(df = 1, location = location, scale = scale)
+cauchy <- function(location = 0, scale = NULL, autoscale = TRUE) {
+  student_t(df = 1, location = location, scale = scale, autoscale)
 }
 
 #' @rdname priors
 #' @export
-hs <- function(df = 3) {
+hs <- function(df = 3, global_df = 1, global_scale = 1) {
   validate_parameter_value(df)
-  nlist(dist = "hs", df, location = 0, scale = 1)
+  validate_parameter_value(global_df)
+  validate_parameter_value(global_scale)
+  nlist(dist = "hs", df, location = 0, scale = 1, global_df, global_scale)
 }
 
 #' @rdname priors
 #' @export
-hs_plus <- function(df1 = 3, df2 = 3) {
+hs_plus <- function(df1 = 3, df2 = 3, global_df = 1, global_scale = 1) {
   validate_parameter_value(df1)
   validate_parameter_value(df2)
+  validate_parameter_value(global_df)
+  validate_parameter_value(global_scale)
   # scale gets used as a second df hyperparameter
-  nlist(dist = "hs_plus", df = df1, location = 0, scale = df2)
+  nlist(dist = "hs_plus", df = df1, location = 0, scale = df2, global_df, global_scale)
+}
+
+#' @rdname priors
+#' @export
+laplace <- function(location = 0, scale = NULL, autoscale = TRUE) {
+  nlist(dist = "laplace", df = NA, location, scale, autoscale)
+}
+
+#' @rdname priors
+#' @export
+lasso <- function(df = 1, location = 0, scale = NULL, autoscale = TRUE) {
+  nlist(dist = "lasso", df, location, scale, autoscale)
+}
+
+#' @rdname priors
+#' @export
+product_normal <- function(df = 2, location = 0, scale = 1) {
+  validate_parameter_value(df)
+  stopifnot(all(df >= 2), all(df == as.integer(df)))
+  validate_parameter_value(scale)
+  nlist(dist = "product_normal", df, location, scale)
+}
+
+#' @rdname priors
+#' @export
+#' @param rate Prior rate for the exponential distribution. Defaults to
+#'   \code{1}. For the exponential distribution, the rate parameter is the
+#'   \emph{reciprocal} of the mean.
+#' 
+exponential <- function(rate = 1) {
+  stopifnot(length(rate) == 1)
+  validate_parameter_value(rate)
+  nlist(dist = "exponential", df = NA, location = NA, scale = 1/rate)
 }
 
 #' @rdname priors
@@ -372,33 +508,6 @@ R2 <- function(location = NULL, what = c("mode", "mean", "median", "log")) {
   list(dist = "R2", location = location, what = what, df = 0, scale = 0)
 }
 
-#' @rdname priors
-#' @export 
-#' @param prior_scale_for_dispersion Prior scale for the standard error of the 
-#'   regression in Gaussian models, which is given a half-Cauchy prior truncated
-#'   at zero.
-#' @param min_prior_scale Minimum prior scale for the intercept and 
-#'   coefficients.
-#' @param scaled A logical scalar, defaulting to \code{TRUE}. If \code{TRUE} 
-#'   then the scales of the priors on the regression coefficients may be 
-#'   additionally modified internally by \pkg{rstanarm} as follows. First, if
-#'   \emph{response} is Gaussian, the prior scales also multiplied by 
-#'   \code{2*sd(y)}. Additionally, if the \code{QR} argument to the model
-#'   fitting function (e.g. \code{stan_glm}) is \code{FALSE} then: for a 
-#'   predictor with only one value nothing is changed; for a predictor \code{x} 
-#'   with exactly two unique values, we take the user-specified (or default) 
-#'   scale(s) for the selected priors and divide by the range of \code{x}; for a
-#'   predictor \code{x} with more than two unique values, we divide the prior 
-#'   scale(s) by \code{2*sd(x)}.
-#'   
-prior_options <- function(prior_scale_for_dispersion = 5, 
-                          min_prior_scale = 1e-12, 
-                          scaled = TRUE) {
-  validate_parameter_value(prior_scale_for_dispersion)
-  validate_parameter_value(min_prior_scale)
-  nlist(scaled, min_prior_scale, prior_scale_for_dispersion)
-}
-
 
 make_eta <- function(location, what = c("mode", "mean", "median", "log"), K) {
   if (is.null(location)) 
