@@ -17,6 +17,7 @@
 
 #' @rdname stan_glm
 #' @export
+#' @param prior_ops Deprecated. See \link{rstanarm-deprecated} for details.
 #' @param group A list, possibly of length zero (the default), but otherwise
 #'   having the structure of that produced by \code{\link[lme4]{mkReTrms}} to
 #'   indicate the group-specific part of the model. In addition, this list must
@@ -29,13 +30,25 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
                          ...,
                          prior = normal(),
                          prior_intercept = normal(),
-                         prior_ops = prior_options(),
+                         prior_aux = cauchy(0, 5),
+                         prior_ops = NULL,
                          group = list(),
                          prior_PD = FALSE, 
                          algorithm = c("sampling", "optimizing", 
                                        "meanfield", "fullrank"), 
                          adapt_delta = NULL, QR = FALSE, sparse = FALSE) {
   
+  # prior_ops deprecated but make sure it still works until 
+  # removed in future release
+  if (!is.null(prior_ops)) {
+    tmp <- .support_deprecated_prior_options(prior, prior_intercept, 
+                                             prior_aux, prior_ops)
+    prior <- tmp[["prior"]]
+    prior_intercept <- tmp[["prior_intercept"]]
+    prior_aux <- tmp[["prior_aux"]]
+    prior_ops <- NULL
+  }
+  
   algorithm <- match.arg(algorithm)
   family <- validate_family(family)
   supported_families <- c("binomial", "gaussian", "Gamma", "inverse.gaussian",
@@ -44,16 +57,7 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
   if (!length(fam)) 
     stop("'family' must be one of ", paste(supported_families, collapse = ", "))
   
-  supported_links <- switch(
-    supported_families[fam],
-    binomial = c("logit", "probit", "cauchit", "log", "cloglog"),
-    gaussian = c("identity", "log", "inverse"),
-    Gamma = c("identity", "log", "inverse"),
-    inverse.gaussian = c("identity", "log", "inverse", "1/mu^2"),
-    "neg_binomial_2" = , # intentional
-    poisson = c("log", "identity", "sqrt"),
-    stop("unsupported family")
-  )
+  supported_links <- supported_glm_links(supported_families[fam])
   link <- which(supported_links == family$link)
   if (!length(link)) 
     stop("'link' must be one of ", paste(supported_links, collapse = ", "))
@@ -62,49 +66,69 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
     stop("To specify 'y' as proportion of successes and 'weights' as ",
          "number of trials please use stan_glm rather than calling ",
          "stan_glm.fit directly.")
-  if (is.binomial(family$family)) {
-    if (NCOL(y) == 1L) {
-      if (is.numeric(y) || is.logical(y)) 
-        y <- as.integer(y)
-      if (is.factor(y)) 
-        y <- fac2bin(y)
-      if (!all(y %in% c(0L, 1L))) 
-        stop("y values must be 0 or 1 for bernoulli regression.")
-    } else {
-      if (!isTRUE(NCOL(y) == 2L))
-        stop("y should either be a vector or a matrix 1 or 2 columns.")
-      trials <- as.integer(y[, 1L] + y[, 2L])
-      y <- as.integer(y[, 1L])
-    }
+  
+  y <- validate_glm_outcome_support(y, family)
+  if (is.binomial(family$family) && NCOL(y) == 2L) {
+    trials <- as.integer(y[, 1L] + y[, 2L])
+    y <- as.integer(y[, 1L])
   }
 
   # useless assignments to pass R CMD check
-  has_intercept <- min_prior_scale <- prior_df <- prior_df_for_intercept <-
-    prior_dist <- prior_dist_for_intercept <- prior_mean <- prior_mean_for_intercept <-
-    prior_scale_for_dispersion <- scaled <- NULL
+  has_intercept <- 
+    prior_df <- prior_df_for_intercept <- prior_df_for_aux <-
+    prior_dist <- prior_dist_for_intercept <- prior_dist_for_aux <- 
+    prior_mean <- prior_mean_for_intercept <- prior_mean_for_aux <- 
+    prior_scale <- prior_scale_for_intercept <- prior_scale_for_aux <- 
+    prior_autoscale <- prior_autoscale_for_intercept <- 
+    global_prior_scale <- global_prior_df <- NULL
   
   x_stuff <- center_x(x, sparse)
   for (i in names(x_stuff)) # xtemp, xbar, has_intercept
     assign(i, x_stuff[[i]])
   nvars <- ncol(xtemp)
-  
-  for (i in names(prior_ops)) # scaled, min_prior_dispersion, prior_scale_for_dispersion
-    assign(i, prior_ops[[i]])
-  
-  ok_dists <- nlist("normal", student_t = "t", "cauchy", "hs", "hs_plus")
+
+  ok_dists <- nlist("normal", student_t = "t", "cauchy", "hs", "hs_plus", 
+                    "laplace", "lasso", "product_normal")
   ok_intercept_dists <- ok_dists[1:3]
+  ok_aux_dists <- c(ok_dists[1:3], exponential = "exponential")
   
   # prior distributions
-  prior_stuff <- handle_glm_prior(prior, nvars, family$link, default_scale = 2.5)
-  for (i in names(prior_stuff)) # prior_{dist, mean, scale, df}
+  prior_stuff <- handle_glm_prior(
+    prior,
+    nvars,
+    link = family$link,
+    default_scale = 2.5,
+    ok_dists = ok_dists
+  )
+  # prior_{dist, mean, scale, df, dist_name, autoscale}, global_prior_df, global_prior_scale
+  for (i in names(prior_stuff))
     assign(i, prior_stuff[[i]])
-  prior_intercept_stuff <- handle_glm_prior(prior_intercept, nvars = 1, default_scale = 10,
-                                            family$link, ok_dists = 
-                                            nlist("normal", student_t = "t", "cauchy"))
+  
+  prior_intercept_stuff <- handle_glm_prior(
+    prior_intercept,
+    nvars = 1,
+    default_scale = 10,
+    link = family$link,
+    ok_dists = ok_intercept_dists
+  )
+  # prior_{dist, mean, scale, df, dist_name, autoscale}_for_intercept
   names(prior_intercept_stuff) <- paste0(names(prior_intercept_stuff), "_for_intercept")
-  for (i in names(prior_intercept_stuff)) # prior_{dist, mean, scale, df}_for_intercept
+  for (i in names(prior_intercept_stuff))
     assign(i, prior_intercept_stuff[[i]])
   
+  prior_aux_stuff <-
+    handle_glm_prior(
+      prior_aux,
+      nvars = 1,
+      default_scale = 5,
+      link = NULL, # don't need to adjust scale based on logit vs probit
+      ok_dists = ok_aux_dists
+    )
+  # prior_{dist, mean, scale, df, dist_name, autoscale}_for_aux
+  names(prior_aux_stuff) <- paste0(names(prior_aux_stuff), "_for_aux")
+  for (i in names(prior_aux_stuff)) 
+    assign(i, prior_aux_stuff[[i]])
+  
   famname <- supported_families[fam]
   is_bernoulli <- is.binomial(famname) && all(y %in% 0:1)
   is_nb <- is.nb(famname)
@@ -123,14 +147,17 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
       stop("To use this combination of family and link ", 
            "the model must have an intercept.")
   }
-  
-  if (scaled && prior_dist > 0L) {
+
+  if (prior_dist > 0L) {
     if (is_gaussian) {
       ss <- 2 * sd(y)
-      prior_scale <- ss * prior_scale
-      prior_scale_for_intercept <-  ss * prior_scale_for_intercept
+      if (prior_autoscale) 
+        prior_scale <- ss * prior_scale
+      if (prior_autoscale_for_intercept && prior_dist_for_intercept > 0L) 
+        prior_scale_for_intercept <-  ss * prior_scale_for_intercept
     }
-    if (!QR) 
+    if (!QR && prior_autoscale) {
+      min_prior_scale <- 1e-12 # used to be set in prior_options()
       prior_scale <- pmax(min_prior_scale, prior_scale / 
              apply(xtemp, 2L, FUN = function(x) {
                num.categories <- length(unique(x))
@@ -139,8 +166,10 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
                else if (num.categories > 2) x.scale <- 2 * sd(x)
                return(x.scale)
              }))
+    }
   }
-  prior_scale <- as.array(pmin(.Machine$double.xmax, prior_scale))
+  prior_scale <- 
+    as.array(pmin(.Machine$double.xmax, prior_scale))
   prior_scale_for_intercept <- 
     min(.Machine$double.xmax, prior_scale_for_intercept)
   
@@ -148,7 +177,7 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
     if (ncol(xtemp) <= 1)
       stop("'QR' can only be specified when there are multiple predictors.")
     if (sparse)
-      stop("'QR' and 'sparse' cannot both be TRUE")
+      stop("'QR' and 'sparse' cannot both be TRUE.")
     cn <- colnames(xtemp)
     decomposition <- qr(xtemp)
     sqrt_nm1 <- sqrt(nrow(xtemp) - 1L)
@@ -161,12 +190,40 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
   
   # create entries in the data block of the .stan file
   standata <- nlist(
-    N = nrow(xtemp), K = ncol(xtemp), xbar = as.array(xbar), dense_X = !sparse,
-    link, has_weights = length(weights) > 0, has_offset = length(offset) > 0,
-    prior_dist, prior_mean, prior_scale, prior_df, 
-    prior_dist_for_intercept, prior_scale_for_intercept = c(prior_scale_for_intercept), 
+    N = nrow(xtemp),
+    K = ncol(xtemp),
+    xbar = as.array(xbar),
+    dense_X = !sparse,
+    link,
+    has_weights = length(weights) > 0,
+    has_offset = length(offset) > 0,
+    has_intercept,
+    prior_PD,
+    prior_dist,
+    prior_mean,
+    prior_scale,
+    prior_df,
+    prior_dist_for_intercept,
+    prior_scale_for_intercept = c(prior_scale_for_intercept),
     prior_mean_for_intercept = c(prior_mean_for_intercept),
-    prior_df_for_intercept = c(prior_df_for_intercept), has_intercept, prior_PD)
+    prior_df_for_intercept = c(prior_df_for_intercept), 
+    global_prior_df, global_prior_scale, # for hs priors
+    has_intercept, prior_PD,
+    z_dim = 0,  # betareg data
+    link_phi = 0,
+    betareg_z = array(0, dim = c(nrow(xtemp), 0)),
+    has_intercept_z = 0,
+    zbar = array(0, dim = c(0)),
+    prior_dist_z = 0, prior_mean_z = integer(), prior_scale_z = integer(), 
+    prior_df_z = integer(), global_prior_scale_z = 0,
+    prior_dist_for_intercept_z = 0, prior_mean_for_intercept_z = 0,
+    prior_scale_for_intercept_z = 0, prior_df_for_intercept_z = 0,
+    prior_df_for_intercept = c(prior_df_for_intercept),
+    prior_dist_for_aux = prior_dist_for_aux,
+    num_normals = if(prior_dist == 7) as.integer(prior_df) else integer(0),
+    num_normals_z = integer(0)
+    # mean,df,scale for dispersion added below depending on family
+  )
 
   # make a copy of user specification before modifying 'group' (used for keeping
   # track of priors)
@@ -176,7 +233,10 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
     check_reTrms(group)
     decov <- group$decov
     Z <- t(group$Zt)
-    group <- pad_reTrms(Ztlist = group$Ztlist, cnms = group$cnms, flist = group$flist)
+    group <-
+      pad_reTrms(Ztlist = group$Ztlist,
+                 cnms = group$cnms,
+                 flist = group$flist)
     Z <- group$Z
     p <- sapply(group$cnms, FUN = length)
     l <- sapply(attr(group$flist, "assign"), function(i) 
@@ -216,7 +276,9 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
     standata$len_regularization <- sum(p > 1)
     standata$regularization <- 
       as.array(maybe_broadcast(decov$regularization, sum(p > 1)))
-    
+    standata$special_case <- all(sapply(group$cnms, FUN = function(x) {
+      length(x) == 1 && x == "(Intercept)"
+    }))
   } else { # !length(group)
     standata$t <- 0L
     standata$p <- integer(0)
@@ -234,6 +296,7 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
       standata$v <- integer(0)
       standata$u <- integer(0)
     }
+    standata$special_case <- 0L
     standata$shape <- standata$scale <- standata$concentration <-
       standata$regularization <- rep(0, 0)
     standata$len_concentration <- 0L
@@ -248,8 +311,7 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
       standata$v_X <- parts$v
       standata$u_X <- parts$u
       standata$X <- array(0, dim = c(0L, dim(xtemp)))
-    }
-    else {
+    } else {
       standata$X <- array(xtemp, dim = c(1L, dim(xtemp)))
       standata$nnz_X <- 0L
       standata$w_X <- double(0)
@@ -263,17 +325,22 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
 
   # call stan() to draw from posterior distribution
   if (is_continuous) {
-    standata$prior_scale_for_dispersion <- 
-      prior_scale_for_dispersion %ORifINF% 0
+    standata$ub_y <- Inf
+    standata$lb_y <- if (is_gaussian) -Inf else 0
+    standata$prior_scale_for_aux <- prior_scale_for_aux %ORifINF% 0
+    standata$prior_df_for_aux <- c(prior_df_for_aux)
+    standata$prior_mean_for_aux <- c(prior_mean_for_aux)
     standata$family <- switch(family$family, 
                               gaussian = 1L, 
                               Gamma = 2L,
                               3L)
     stanfit <- stanmodels$continuous
   } else if (is.binomial(famname)) {
-    standata$prior_scale_for_dispersion <- 
-      if (!length(group) || prior_scale_for_dispersion == Inf) 
-        0 else prior_scale_for_dispersion
+    standata$prior_scale_for_aux <- 
+      if (!length(group) || prior_scale_for_aux == Inf) 
+        0 else prior_scale_for_aux
+    standata$prior_mean_for_aux <- 0
+    standata$prior_df_for_aux <- 0
     standata$family <- 1L # not actually used
     if (is_bernoulli) {
       y0 <- y == 0
@@ -292,8 +359,7 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
         standata$w_X1 = parts1$w
         standata$v_X1 = parts1$v
         standata$u_X1 = parts1$u
-      }
-      else {
+      } else {
         standata$X0 <- array(xtemp[y0, , drop = FALSE], dim = c(1, sum(y0), ncol(xtemp)))
         standata$X1 <- array(xtemp[y1, , drop = FALSE], dim = c(1, sum(y1), ncol(xtemp)))
         standata$nnz_X0 = 0L 
@@ -332,13 +398,15 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
     }
   } else if (is.poisson(famname)) {
     standata$family <- 1L
-    standata$prior_scale_for_dispersion <- 
-      prior_scale_for_dispersion %ORifINF% 0
+    standata$prior_scale_for_aux <- prior_scale_for_aux %ORifINF% 0
+    standata$prior_mean_for_aux <- 0
+    standata$prior_df_for_aux <- 0
     stanfit <- stanmodels$count 
   } else if (is_nb) {
     standata$family <- 2L
-    standata$prior_scale_for_dispersion <- 
-      prior_scale_for_dispersion %ORifINF% 0
+    standata$prior_scale_for_aux <- prior_scale_for_aux %ORifINF% 0
+    standata$prior_df_for_aux <- c(prior_df_for_aux)
+    standata$prior_mean_for_aux <- c(prior_mean_for_aux)
     stanfit <- stanmodels$count
   } else if (is_gamma) {
     # nothing
@@ -350,23 +418,25 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
   prior_info <- summarize_glm_prior(
     user_prior = prior_stuff,
     user_prior_intercept = prior_intercept_stuff,
+    user_prior_aux = prior_aux_stuff,
     user_prior_covariance = user_covariance,
-    user_prior_ops = prior_ops,
     has_intercept = has_intercept,
     has_predictors = nvars > 0,
     adjusted_prior_scale = prior_scale,
-    adjusted_prior_intercept_scale = prior_scale_for_intercept
+    adjusted_prior_intercept_scale = prior_scale_for_intercept,
+    family = family
   )
   
   pars <- c(if (has_intercept) "alpha", 
             "beta", 
             if (length(group)) "b",
-            if (is_continuous | is_nb) "dispersion",
+            if (is_continuous | is_nb) "aux",
             if (standata$len_theta_L) "theta_L",
             "mean_PPD")
   if (algorithm == "optimizing") {
     out <- optimizing(stanfit, data = standata, 
                       draws = 1000, constrained = TRUE, ...)
+    check_stanfit(out)
     new_names <- names(out$par)
     mark <- grepl("^beta\\[[[:digit:]]+\\]$", new_names)
     if (QR) {
@@ -375,11 +445,11 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
     }
     new_names[mark] <- colnames(xtemp)
     new_names[new_names == "alpha[1]"] <- "(Intercept)"
-    new_names[grepl("dispersion(\\[1\\])?$", new_names)] <- 
+    new_names[grepl("aux(\\[1\\])?$", new_names)] <- 
       if (is_gaussian) "sigma" else
         if (is_gamma) "shape" else
           if (is_ig) "lambda" else 
-            if (is_nb) "overdispersion" else NA
+            if (is_nb) "reciprocal_dispersion" else NA
     names(out$par) <- new_names
     colnames(out$theta_tilde) <- new_names
     out$stanfit <- suppressMessages(sampling(stanfit, data = standata, 
@@ -404,6 +474,7 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
       if (algorithm == "meanfield" && !QR) 
         msg_meanfieldQR()
     }
+    check_stanfit(stanfit)
     if (QR) {
       thetas <- extract(stanfit, pars = "beta", inc_warmup = TRUE, 
                         permuted = FALSE)
@@ -434,10 +505,14 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
       else for (chain in 1:end) {
         stanfit@sim$samples[[chain]][[shift + 1]] <- Sigma[, chain]
       }
-      Sigma_nms <- unlist(lapply(cnms, FUN = function(grp) {
+      Sigma_nms <- lapply(cnms, FUN = function(grp) {
         nm <- outer(grp, grp, FUN = paste, sep = ",")
         nm[lower.tri(nm, diag = TRUE)]
-      }))
+      })
+      for (j in seq_along(Sigma_nms)) {
+        Sigma_nms[[j]] <- paste0(nms[j], ":", Sigma_nms[[j]])
+      }
+      Sigma_nms <- unlist(Sigma_nms)
     }
     new_names <- c(if (has_intercept) "(Intercept)", 
                    colnames(xtemp), 
@@ -445,7 +520,7 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
                    if (is_gaussian) "sigma", 
                    if (is_gamma) "shape", 
                    if (is_ig) "lambda",
-                   if (is_nb) "overdispersion", 
+                   if (is_nb) "reciprocal_dispersion", 
                    if (standata$len_theta_L) paste0("Sigma[", Sigma_nms, "]"),
                    "mean_PPD", 
                    "log-posterior")
@@ -455,6 +530,91 @@ stan_glm.fit <- function(x, y, weights = rep(1, NROW(x)),
 }
 
 
+
+# internal ----------------------------------------------------------------
+
+# @param famname string naming the family
+# @return character vector of supported link functions for the family
+supported_glm_links <- function(famname) {
+  switch(
+    famname,
+    binomial = c("logit", "probit", "cauchit", "log", "cloglog"),
+    gaussian = c("identity", "log", "inverse"),
+    Gamma = c("identity", "log", "inverse"),
+    inverse.gaussian = c("identity", "log", "inverse", "1/mu^2"),
+    "neg_binomial_2" = , # intentional
+    poisson = c("log", "identity", "sqrt"),
+    stop("unsupported family")
+  )
+}
+
+
+# Verify that outcome values match support implied by family object
+#
+# @param y outcome variable
+# @param family family object
+# @return y (possibly slightly modified) unless an error is thrown
+#
+validate_glm_outcome_support <- function(y, family) {
+  .is_count <- function(x) {
+    all(x >= 0) && all(abs(x - round(x)) < .Machine$double.eps^0.5)
+  }
+  
+  fam <- family$family
+  
+  if (!is.binomial(fam)) {
+    # make sure y has ok dimensions (matrix only allowed for binomial models)
+    if (length(dim(y)) > 1) {
+      if (NCOL(y) == 1) {
+        y <- y[, 1]
+      } else {
+        stop("Except for binomial models the outcome variable ",
+             "should not have multiple columns.", 
+             call. = FALSE)
+      }
+    }
+    
+    # check that values match support for non-binomial models
+    if (is.gaussian(fam)) {
+      return(y)
+    } else if (is.gamma(fam) && any(y <= 0)) {
+      stop("All outcome values must be positive for gamma models.", 
+           call. = FALSE)
+    } else if (is.ig(fam) && any(y <= 0)) {
+      stop("All outcome values must be positive for inverse-Gaussian models.", 
+           call. = FALSE)
+    } else if (is.poisson(fam) && !.is_count(y)) {
+      stop("All outcome values must be counts for Poisson models",
+           call. = FALSE)
+    } else if (is.nb(fam) && !.is_count(y)) {
+      stop("All outcome values must be counts for negative binomial models",
+           call. = FALSE)
+    }
+  } else { # binomial models
+    if (NCOL(y) == 1L) {
+      if (is.numeric(y) || is.logical(y)) 
+        y <- as.integer(y)
+      if (is.factor(y)) 
+        y <- fac2bin(y)
+      if (!all(y %in% c(0L, 1L))) 
+        stop("All outcome values must be 0 or 1 for Bernoulli models.", 
+             call. = FALSE)
+    } else if (isTRUE(NCOL(y) == 2L)) {
+      if (!.is_count(y))
+        stop("All outcome values must be counts for binomial models.",
+             call. = FALSE)
+    } else {
+      stop("For binomial models the outcome should be a vector or ",
+           "a matrix with 2 columns.", 
+           call. = FALSE)
+    }
+  }
+  
+  return(y)
+}
+
+
+
 # Add extra level _NEW_ to each group
 # 
 # @param Ztlist ranef indicator matrices
@@ -521,6 +681,7 @@ make_b_nms <- function(group) {
   for (i in seq_along(group$cnms)) {
     nm <- group_nms[i]
     nms_i <- paste(group$cnms[[i]], nm)
+    levels(group$flist[[nm]]) <- gsub(" ", "_", levels(group$flist[[nm]]))
     if (length(nms_i) == 1) {
       b_nms <- c(b_nms, paste0(nms_i, ":", levels(group$flist[[nm]])))
     } else {
@@ -534,32 +695,35 @@ make_b_nms <- function(group) {
 # Create "prior.info" attribute needed for prior_summary()
 #
 # @param user_* The user's prior, prior_intercept, prior_covariance, and 
-#   prior_options specifications. For prior and prior_intercept these should be
+#   prior_aux specifications. For prior and prior_intercept these should be
 #   passed in after broadcasting the df/location/scale arguments if necessary.
 # @param has_intercept T/F, does model have an intercept?
 # @param has_predictors T/F, does model have predictors?
-# @param adjusted_prior_* adjusted scales computed if prior_ops$scaled is TRUE
+# @param adjusted_prior_* adjusted scales computed if using autoscaled priors
+# @param family Family object.
 # @return A named list with components 'prior', 'prior_intercept', and possibly 
-#   'prior_covariance', each of which itself is a list containing the needed
-#   values for prior_summary.
+#   'prior_covariance' and 'prior_aux' each of which itself is a list
+#   containing the needed values for prior_summary.
 summarize_glm_prior <-
   function(user_prior,
            user_prior_intercept,
+           user_prior_aux,
            user_prior_covariance,
-           user_prior_ops,
            has_intercept, 
            has_predictors,
            adjusted_prior_scale,
-           adjusted_prior_intercept_scale) {
-    rescaled <- isTRUE(user_prior_ops$scaled)
+           adjusted_prior_intercept_scale, 
+           family) {
     rescaled_coef <-
-      rescaled && has_predictors &&
+      user_prior$prior_autoscale && 
+      has_predictors &&
       !is.na(user_prior$prior_dist_name) &&
       !all(user_prior$prior_scale == adjusted_prior_scale)
     rescaled_int <-
-      rescaled && has_intercept &&
+      user_prior_intercept$prior_autoscale_for_intercept &&
+      has_intercept &&
       !is.na(user_prior_intercept$prior_dist_name_for_intercept) &&
-      (user_prior_intercept$prior_scale != adjusted_prior_intercept_scale)
+      (user_prior_intercept$prior_scale_for_intercept != adjusted_prior_intercept_scale)
     
     if (has_predictors && user_prior$prior_dist_name %in% "t") {
       if (all(user_prior$prior_df == 1)) {
@@ -576,6 +740,13 @@ summarize_glm_prior <-
         user_prior_intercept$prior_dist_name_for_intercept <- "student_t"
       }
     }
+    if (user_prior_aux$prior_dist_name_for_aux %in% "t") {
+      if (all(user_prior_aux$prior_df_for_aux == 1)) {
+        user_prior_aux$prior_dist_name_for_aux <- "cauchy"
+      } else {
+        user_prior_aux$prior_dist_name_for_aux <- "student_t"
+      }
+    }
     prior_list <- list(
       prior = 
         if (!has_predictors) NULL else with(user_prior, list(
@@ -584,7 +755,8 @@ summarize_glm_prior <-
           scale = prior_scale,
           adjusted_scale = if (rescaled_coef)
             adjusted_prior_scale else NULL,
-          df = if (prior_dist_name %in% c("student_t", "hs", "hs_plus"))
+          df = if (prior_dist_name %in% c
+                   ("student_t", "hs", "hs_plus", "lasso", "product_normal"))
             prior_df else NULL
         )),
       prior_intercept = 
@@ -601,5 +773,28 @@ summarize_glm_prior <-
     if (length(user_prior_covariance))
       prior_list$prior_covariance <- user_prior_covariance
     
+    aux_name <- .rename_aux(family)
+    prior_list$prior_aux <- if (is.na(aux_name)) 
+      NULL else with(user_prior_aux, list(
+        dist = prior_dist_name_for_aux,
+        location = if (prior_dist_name_for_aux != "exponential")
+          prior_mean_for_aux else NULL,
+        scale = if (prior_dist_name_for_aux != "exponential")
+          prior_scale_for_aux else NULL,
+        df = if (prior_dist_name_for_aux %in% "student_t")
+          prior_df_for_aux else NULL, 
+        rate = if (prior_dist_name_for_aux %in% "exponential")
+          1 / prior_scale_for_aux else NULL,
+        aux_name = aux_name
+      ))
+      
     return(prior_list)
   }
+
+.rename_aux <- function(family) {
+  fam <- family$family
+  if (is.gaussian(fam)) "sigma" else
+    if (is.gamma(fam)) "shape" else
+      if (is.ig(fam)) "lambda" else 
+        if (is.nb(fam)) "reciprocal_dispersion" else NA
+}
