@@ -28,6 +28,7 @@
 #' @template return-stanreg-object
 #' @template see-also
 #' @template args-priors
+#' @template args-prior_aux
 #' @template args-prior_PD
 #' @template args-algorithm
 #' @template args-adapt_delta
@@ -51,7 +52,7 @@
 #' @details The \code{stan_glmer} function is similar in syntax to 
 #'   \code{\link[lme4]{glmer}} but rather than performing (restricted) maximum 
 #'   likelihood estimation of generalized linear models, Bayesian estimation is 
-#'   performed via MCMC. The Bayesian model adds independent priors on the 
+#'   performed via MCMC. The Bayesian model adds priors on the 
 #'   regression coefficients (in the same way as \code{\link{stan_glm}}) and
 #'   priors on the terms of a decomposition of the covariance matrices of the
 #'   group-specific parameters. See \code{\link{priors}} for more information
@@ -60,9 +61,9 @@
 #'   The \code{stan_lmer} function is equivalent to \code{stan_glmer} with 
 #'   \code{family = gaussian(link = "identity")}. 
 #'   
-#'   The \code{stan_glmer.nb} function, which takes the extra argument
-#'   \code{link}, is a simple wrapper for \code{stan_glmer} with 
-#'   \code{family = \link{neg_binomial_2}(link)}.
+#'   The \code{stan_glmer.nb} function, which takes the extra argument 
+#'   \code{link}, is a wrapper for \code{stan_glmer} with \code{family = 
+#'   \link{neg_binomial_2}(link)}.
 #'   
 #'   
 #' @seealso The vignette for \code{stan_glmer} and the \emph{Hierarchical 
@@ -80,7 +81,7 @@ stan_glmer <- function(formula, data = NULL, family = gaussian,
                        na.action = getOption("na.action", "na.omit"), 
                        offset, contrasts = NULL, ...,
                        prior = normal(), prior_intercept = normal(),
-                       prior_ops = prior_options(),
+                       prior_aux = cauchy(0, 5),
                        prior_covariance = decov(), prior_PD = FALSE, 
                        algorithm = c("sampling", "meanfield", "fullrank"), 
                        adapt_delta = NULL, QR = FALSE, sparse = FALSE) {
@@ -90,7 +91,7 @@ stan_glmer <- function(formula, data = NULL, family = gaussian,
   family <- validate_family(family)
   mc[[1]] <- quote(lme4::glFormula)
   mc$control <- make_glmerControl()
-  mc$prior <- mc$prior_intercept <- mc$prior_covariance <- mc$prior_ops <-
+  mc$prior <- mc$prior_intercept <- mc$prior_covariance <- mc$prior_aux <-
     mc$prior_PD <- mc$algorithm <- mc$scale <- mc$concentration <- mc$shape <-
     mc$adapt_delta <- mc$... <- mc$QR <- mc$sparse <- NULL
   glmod <- eval(mc, parent.frame())
@@ -105,17 +106,17 @@ stan_glmer <- function(formula, data = NULL, family = gaussian,
     prior <- list()
   if (is.null(prior_intercept)) 
     prior_intercept <- list()
+  if (is.null(prior_aux)) 
+    prior_aux <- list()
   if (is.null(prior_covariance))
     stop("'prior_covariance' can't be NULL.", call. = FALSE)
-  if (!length(prior_ops)) 
-    prior_ops <- list(scaled = FALSE, prior_scale_for_dispersion = Inf)
   group <- glmod$reTrms
   group$decov <- prior_covariance
   algorithm <- match.arg(algorithm)
   stanfit <- stan_glm.fit(x = X, y = y, weights = weights,
                           offset = offset, family = family,
                           prior = prior, prior_intercept = prior_intercept,
-                          prior_ops = prior_ops, prior_PD = prior_PD, 
+                          prior_aux = prior_aux, prior_PD = prior_PD, 
                           algorithm = algorithm, adapt_delta = adapt_delta,
                           group = group, QR = QR, sparse = sparse, ...)
 
@@ -133,25 +134,6 @@ stan_glmer <- function(formula, data = NULL, family = gaussian,
   return(out)
 }
 
-make_Sigma <- function(mat, cnms) {
-  useSc <- "sigma" %in% colnames(mat)
-  if (useSc) sc <- mat[,"sigma"]
-  else sc <- 1
-  theta <- mat[,grepl("^theta\\[", colnames(mat)), drop = FALSE]
-  nc <- vapply(cnms, FUN = length, FUN.VALUE = 1L)
-  nms <- names(cnms)
-  Sigma_list <- apply(theta, 1, FUN = mkVarCorr, 
-                      sc = 1, cnms = cnms, nc = nc, nms = nms)
-  add <- function(x) Reduce("+", x)
-  Sigma <- sapply(Sigma_list[[1]], simplify = FALSE, FUN = `*`, y = 0)
-  for (i in seq_along(Sigma)) {
-    Sigma[[i]] <- add(lapply(Sigma_list, FUN = function(x) x[[i]])) / length(Sigma_list)
-    attr(Sigma[[i]], "stddev") <- sqrt(diag(Sigma[[i]]))
-    attr(Sigma[[i]], "correlation") <- cov2cor(Sigma[[i]])
-  }
-  Sigma <- structure(Sigma, useSc = useSc, sc = mean(sc), class = "VarCorr.merMod")
-  return(Sigma)
-}
 
 #' @rdname stan_glmer
 #' @export
@@ -165,7 +147,7 @@ stan_lmer <- function(formula,
                       ...,
                       prior = normal(),
                       prior_intercept = normal(),
-                      prior_ops = prior_options(),
+                      prior_aux = cauchy(0, 5),
                       prior_covariance = decov(),
                       prior_PD = FALSE,
                       algorithm = c("sampling", "meanfield", "fullrank"),
@@ -201,7 +183,7 @@ stan_glmer.nb <- function(formula,
                           ...,
                           prior = normal(),
                           prior_intercept = normal(),
-                          prior_ops = prior_options(),
+                          prior_aux = cauchy(0, 5),
                           prior_covariance = decov(),
                           prior_PD = FALSE,
                           algorithm = c("sampling", "meanfield", "fullrank"),
