@@ -104,11 +104,10 @@ stan_polr.fit <- function(x, y, wt = NULL, offset = NULL,
                     prior_dist, regularization, prior_counts,
                     is_skewed, shape, rate,
                     # the rest of these are not actually used
-                    has_intercept = 0L, prior_dist_for_intercept = 0L, 
-                    family = 1L,
+                    family = 1L, has_intercept = 0L, 
+                    prior_dist_for_intercept = 0L, prior_dist_for_aux = 0L, 
                     dense_X = TRUE, # sparse is not a viable option
-                    nnz_X = 0L, w_X = double(0), v_X = integer(0), u_X = integer(0)
-  )
+                    nnz_X = 0L, w_X = double(0), v_X = integer(0), u_X = integer(0))
   stanfit <- stanmodels$polr
   if (J > 2) {
     pars <- c("beta", "zeta", "mean_PPD")
@@ -129,7 +128,7 @@ stan_polr.fit <- function(x, y, wt = NULL, offset = NULL,
     stanfit <- rstan::vb(stanfit, pars = pars, data = standata, 
                          algorithm = algorithm, ...)
   }
-  
+  check_stanfit(stanfit)
   thetas <- extract(stanfit, pars = "beta", inc_warmup = TRUE, permuted = FALSE)
   betas <- apply(thetas, 1:2, FUN = function(theta) R_inv %*% theta)
   if (K == 1) for (chain in 1:tail(dim(betas), 1)) {
