@@ -18,6 +18,7 @@
 library(rstanarm)
 library(lme4)
 library(MASS)
+library(betareg)
 SEED <- 12345
 set.seed(SEED)
 ITER <- 10
@@ -26,29 +27,49 @@ REFRESH <- 0
 
 SW <- suppressWarnings
 
-stan_glm1 <- SW(stan_glm(mpg ~ wt + cyl, data = mtcars, iter = ITER,
-                         chains = CHAINS, seed = SEED, refresh = REFRESH))
-stan_glm_opt1 <- stan_glm(mpg ~ wt + cyl, data = mtcars, algorithm = "optimizing",
-                          seed = SEED)
-stan_glm_vb1 <- update(stan_glm_opt1, algorithm = "meanfield", QR = TRUE, iter = 10000)
-glm1 <- glm(mpg ~ wt + cyl, data = mtcars)
+capture.output(
+  stan_glm1 <- SW(stan_glm(mpg ~ wt + cyl, data = mtcars, iter = ITER,
+                           chains = CHAINS, seed = SEED, refresh = REFRESH)),
+  stan_glm_opt1 <- stan_glm(mpg ~ wt + cyl, data = mtcars, algorithm = "optimizing",
+                            seed = SEED),
+  stan_glm_vb1 <- update(stan_glm_opt1, algorithm = "meanfield", QR = TRUE, iter = 10000),
+  glm1 <- glm(mpg ~ wt + cyl, data = mtcars),
+  
+  lmer1 <- lmer(diameter ~ (1|plate) + (1|sample), data = Penicillin),
+  stan_lmer1 <- SW(stan_lmer(diameter ~ (1|plate) + (1|sample), data = Penicillin,
+                             prior_intercept = normal(0, 50, autoscale = FALSE),
+                             prior_aux = normal(0, 10),
+                             iter = ITER, chains = CHAINS, seed = SEED, refresh = REFRESH)),
+  lmer2 <- lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy),
+  stan_lmer2 <- SW(stan_lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy,
+                             iter = ITER, chains = CHAINS, seed = SEED,
+                             refresh = REFRESH)),
+  
+  stan_polr1 <- SW(stan_polr(tobgp ~ agegp, data = esoph, prior = R2(0.2, "mean"),
+                             init_r = 0.1, iter = ITER, chains = CHAINS,
+                             seed = SEED, refresh = REFRESH)),
+  polr1 <- polr(tobgp ~ agegp, data = esoph, Hess = TRUE),
+  
+  stan_gamm41 <- SW(stan_gamm4(mpg ~ s(wt) + cyl, data = mtcars, iter = ITER,
+                               chains = CHAINS, seed = SEED, refresh = REFRESH))
+)
 
-lmer1 <- lmer(diameter ~ (1|plate) + (1|sample), data = Penicillin)
-stan_lmer1 <- SW(stan_lmer(diameter ~ (1|plate) + (1|sample), data = Penicillin,
-                           iter = ITER, chains = CHAINS, seed = SEED,
-                           refresh = REFRESH))
-lmer2 <- lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy)
-stan_lmer2 <- SW(stan_lmer(Reaction ~ Days + (Days | Subject), data = sleepstudy,
-                           iter = ITER, chains = CHAINS, seed = SEED,
-                           refresh = REFRESH))
+N <- 200
+x <- rnorm(N, 2, 1)
+z <- rnorm(N, 2, 1)
+mu <- binomial(link = "logit")$linkinv(1 + 0.2*x)
+phi <- exp(1.5 + 0.4*z)
+y <- rbeta(N, mu * phi, (1 - mu) * phi)
+fake_dat <- data.frame(y, x, z)
+remove(N, x, y, z, mu, phi)
 
-stan_polr1 <- SW(stan_polr(tobgp ~ agegp, data = esoph, prior = R2(0.2, "mean"),
-                           init_r = 0.1, iter = ITER, chains = CHAINS,
-                           seed = SEED, refresh = REFRESH))
-polr1 <- polr(tobgp ~ agegp, data = esoph, Hess = TRUE)
-
-stan_gamm41 <- SW(stan_gamm4(mpg ~ s(wt) + cyl, data = mtcars, iter = ITER,
-                             chains = CHAINS, seed = SEED, refresh = REFRESH))
+capture.output(
+  stan_betareg1 <- stan_betareg(y ~ x | z, data = fake_dat, 
+                                link = "logit", link.phi = "log",
+                                iter = ITER, chains = CHAINS, seed = SEED)
+)
+betareg1 <- betareg(y ~ x | z, data = fake_dat, 
+                    link = "logit", link.phi = "log")
 
 att_names <- function(object) {
   nms <- names(object)
@@ -98,6 +119,13 @@ test_that("stanreg extractor methods work properly", {
   expect_equal(se(example_model), example_model$ses)
   # coef and vcov are different for stan_(g)lmer models and are tested
   # separately later in this file
+  
+  # stan_betareg
+  expect_equal(resid(stan_betareg1), stan_betareg1$residuals)
+  expect_equal(coef(stan_betareg1), stan_betareg1$coefficients)
+  expect_equal(vcov(stan_betareg1), stan_betareg1$covmat)
+  expect_equal(fitted(stan_betareg1), stan_betareg1$fitted.values)
+  expect_equal(se(stan_betareg1), stan_betareg1$ses)
 })
 
 
@@ -115,6 +143,7 @@ test_that("confint method returns correct structure", {
   expect_error(confint(stan_polr1), regexp = "use posterior_interval")
   expect_error(confint(stan_lmer1), regexp = "use posterior_interval")
   expect_error(confint(stan_lmer2), regexp = "use posterior_interval")
+  expect_error(confint(stan_betareg1), regexp = "use posterior_interval")
 })
 
 
@@ -126,15 +155,19 @@ test_that("posterior_interval returns correct structure", {
   expect_silent(ci4 <- posterior_interval(example_model, prob = 0.8, pars = "(Intercept)",
                                regex_pars = "period"))
   expect_silent(ci5 <- posterior_interval(stan_polr1, prob = 0.9))
+  expect_silent(ci6 <- posterior_interval(stan_betareg1, prob = 0.5))
+  
   expect_identical(rownames(ci), c("(Intercept)", "wt", "cyl", "sigma"))
   expect_identical(rownames(ci2), "wt")
-  expect_identical(rownames(ci3), rstanarm:::b_names(rownames(example_model$stan_summary), value = TRUE)[1:15])
+  expect_identical(rownames(ci3), c(paste0("b[(Intercept) herd:", 1:15, "]"), 
+                                    "Sigma[herd:(Intercept),(Intercept)]"))
   expect_identical(rownames(ci4), c("(Intercept)", paste0("period", 2:4)))
   expect_identical(colnames(ci), c("25%", "75%"))
   expect_identical(colnames(ci2), c("2.5%", "97.5%"))
   expect_identical(colnames(ci3), c("2.5%", "97.5%"))
   expect_identical(colnames(ci4), c("10%", "90%"))
   expect_identical(colnames(ci5), c("5%", "95%"))
+  expect_identical(colnames(ci6), c("25%", "75%"))
 
   expect_error(posterior_interval(stan_glm1, type = "HPD"),
                regexp = "only option for 'type' is 'central'")
@@ -190,6 +223,7 @@ test_that("log_lik method works", {
   expect_equal(log_lik(stan_glm1), log_lik(stan_glm1, newdata = mtcars))
   expect_equal(log_lik(stan_polr1), log_lik(stan_polr1, newdata = esoph))
   expect_equal(log_lik(stan_gamm41), log_lik(stan_gamm41, newdata = mtcars))
+  expect_equal(log_lik(stan_betareg1), log_lik(stan_betareg1, newdata = fake_dat))
 })
 
 
@@ -198,6 +232,7 @@ test_that("ngrps is right", {
   expect_equal(ngrps(lmer1), ngrps(stan_lmer1))
   expect_equal(ngrps(lmer2), ngrps(stan_lmer2))
   expect_error(ngrps(stan_glm1), "stan_glmer and stan_lmer models only")
+  expect_error(ngrps(stan_betareg1), "stan_glmer and stan_lmer models only")
 })
 
 test_that("nobs is right", {
@@ -206,6 +241,7 @@ test_that("nobs is right", {
   expect_equal(nobs(glm1), nobs(stan_glm_opt1))
   expect_equal(nobs(glm1), nobs(stan_glm1))
   expect_equal(nobs(polr1), nobs(stan_polr1))
+  expect_equal(nobs(stan_betareg1), nobs(betareg1))
 })
 
 
@@ -215,6 +251,7 @@ test_that("vcov returns correct structure", {
   expect_equal(dimnames(vcov(stan_polr1)), dimnames(vcov(polr1)))
   expect_equal(dimnames(vcov(stan_lmer1)), dimnames(vcov(lmer1)))
   expect_equal(dimnames(vcov(stan_lmer2)), dimnames(vcov(lmer2)))
+  expect_equal(dimnames(vcov(stan_betareg1)), dimnames(vcov(betareg1)))
 })
 
 # sigma --------------------------------------------------------------
@@ -236,6 +273,9 @@ test_that("sigma method works", {
   expect_false(identical(sig, 1))
   expect_double(sig <- rsigma(stan_glm_opt1))
   expect_false(identical(sig, 1))
+  # errors not modeled in stan_betareg 
+  expect_double(sig <- rsigma(stan_betareg1))
+  expect_true(identical(sig, 1))
 })
 
 
@@ -247,7 +287,10 @@ test_that("VarCorr returns correct structure", {
   expect_s3_class(vc_stan2, class(vc_lmer2))
   check_att_names(vc_stan1, vc_lmer1)
   check_att_names(vc_stan2, vc_lmer2)
+  v <- sapply(vc_stan1, "[[", 1)
+  expect_true(length(unique(v)) == length(v))
   expect_error(VarCorr(stan_glm1), "stan_glmer and stan_lmer models only")
+  expect_error(VarCorr(stan_betareg1), "stan_glmer and stan_lmer models only")
 })
 
 
@@ -262,6 +305,7 @@ test_that("ranef returns correct structure", {
   check_sizes(re_stan1, re_lmer1)
   check_sizes(re_stan2, re_lmer2)
   expect_error(ranef(stan_glm1), "stan_glmer and stan_lmer models only")
+  expect_error(ranef(stan_betareg1), "stan_glmer and stan_lmer models only")
 })
 test_that("fixef returns the right coefs", {
   expect_identical(names(fixef(stan_lmer1)), names(fixef(lmer1)))
@@ -276,7 +320,9 @@ test_that("coef returns the right structure", {
   check_sizes(coef_stan2, coef_lmer2)
 })
 test_that("coef ok if any 'ranef' missing from 'fixef'", {
-  stan_lmer3 <- SW(update(stan_lmer2, formula = . ~ (Days | Subject)))
+  SW(capture.output(
+    stan_lmer3 <- update(stan_lmer2, formula = . ~ (Days | Subject))
+  ))
   lmer3 <- update(lmer2, formula = . ~ (Days | Subject))
   coef_stan3 <- coef(stan_lmer3); coef_lmer3 <- coef(lmer3)
   check_att_names(coef_stan3, coef_lmer3)
@@ -370,6 +416,17 @@ test_that("as.matrix, as.data.frame, as.array methods work for MCMC", {
   df <- as.data.frame(stan_polr1, regex_pars = "\\^")
   expect_identical(df, as.data.frame(mat))
   expect_identical(colnames(mat), paste0("agegp^", 4:5))
+  
+  # betareg
+  mat <- as.matrix(stan_betareg1)
+  df <- as.data.frame(stan_betareg1)
+  arr <- as.array(stan_betareg1)
+  expect_identical(df, as.data.frame(mat))
+  expect_identical(mat[1:2, 1], arr[1:2, 1, 1])
+  expect_equal(dim(mat), c(floor(ITER/2) * CHAINS, 4L))
+  expect_equal(dim(arr), c(floor(ITER/2), CHAINS, 4L))
+  expect_identical(last_dimnames(mat), c("(Intercept)", "x", "(phi)_(Intercept)", "(phi)_z"))
+  expect_identical(last_dimnames(arr), last_dimnames(mat))
 })
 
 test_that("as.matrix and as.data.frame work for optimization and vb", {
@@ -416,8 +473,8 @@ test_that("as.matrix and as.array errors & warnings", {
 
 
 
-# terms, formula, model.frame, and model.matrix methods -----------------
-context("terms, formula, model.frame, and model.matrix methods")
+# terms, formula, model.frame, model.matrix, update methods -----------------
+context("terms, formula, model.frame, model.matrix, update methods")
 
 test_that("model.frame works properly", {
   expect_identical(model.frame(stan_glm1), model.frame(glm1))
@@ -430,6 +487,7 @@ test_that("model.frame works properly", {
                    model.frame(lmer1, fixed.only = TRUE))
   expect_identical(model.frame(stan_lmer2, fixed.only = TRUE),
                    model.frame(lmer2, fixed.only = TRUE))
+  expect_identical(model.frame(stan_betareg1), model.frame(betareg1))
 })
 
 test_that("terms works properly", {
@@ -449,6 +507,7 @@ test_that("terms works properly", {
                terms(lmer2, random.only = TRUE))
   expect_error(terms(stan_lmer1, fixed.only = TRUE, random.only = TRUE),
                regexp = "can't both be TRUE")
+  expect_identical(terms(stan_betareg1), terms(betareg1))
 })
 
 test_that("formula works properly", {
@@ -468,6 +527,7 @@ test_that("formula works properly", {
                formula(lmer2, random.only = TRUE))
   expect_error(formula(stan_lmer1, fixed.only = TRUE, random.only = TRUE),
                regexp = "can't both be TRUE")
+  expect_identical(formula(stan_betareg1), formula(betareg1))
 
   tmp <- stan_lmer1
   tmp$formula <- NULL
@@ -480,27 +540,31 @@ test_that("formula works properly", {
 test_that("update works properly", {
   pss <- rstanarm:::posterior_sample_size
 
-  fit <- SW(update(stan_lmer2, iter = ITER * 2, chains = 2 * CHAINS))
-  expect_equal(pss(fit), 4 * pss(stan_lmer2))
+  SW(capture.output(
+    fit1 <- update(stan_lmer2, iter = ITER * 2, chains = 2 * CHAINS),
+    fit2 <- update(stan_glm1, iter = ITER * 2, chains = 2 * CHAINS),
+    fit3 <- update(stan_betareg1, iter = ITER * 2, chains = 2 * CHAINS)
+  ))
+  expect_equal(pss(fit1), 4 * pss(stan_lmer2))
+  expect_equal(pss(fit2), 4 * pss(stan_glm1))
+  expect_equal(pss(fit3), 4 * pss(stan_betareg1))
 
-  fit <- SW(update(stan_glm1, iter = ITER * 2, chains = 2 * CHAINS))
-  expect_equal(pss(fit), 4 * pss(stan_glm1))
-
-  call_only <- update(fit, evaluate = FALSE)
+  call_only <- update(fit1, evaluate = FALSE)
   expect_is(call_only, "call")
-  expect_identical(call_only, getCall(fit))
+  expect_identical(call_only, getCall(fit1))
 
-  expect_error(fit <- update(fit, algorithm = "optimizing"),
+  expect_error(fit2 <- update(fit2, algorithm = "optimizing"),
                regexp = "unknown arguments: chains")
-  expect_identical(fit$algorithm, "sampling")
+  expect_identical(fit2$algorithm, "sampling")
 
-  fit$call <- NULL
-  expect_error(update(fit), regexp = "does not contain a 'call' component")
+  fit2$call <- NULL
+  expect_error(update(fit2), regexp = "does not contain a 'call' component")
 })
 
 
 
 # print and summary -------------------------------------------------------
+context("print and summary methods")
 test_that("print and summary methods ok for mcmc and vb", {
   expect_output(print(example_model, digits = 2), "stan_glmer")
   expect_output(print(example_model, digits = 2), "Error terms")
@@ -511,8 +575,9 @@ test_that("print and summary methods ok for mcmc and vb", {
   expect_output(print(stan_polr1), "Cutpoints")
   expect_output(print(stan_glm_opt1, digits = 5), "stan_glm")
   expect_output(print(stan_glm_vb1, digits = 5), "stan_glm")
+  expect_output(print(stan_betareg1, digits = 2), "stan_betareg")
 
-  expect_silent(s <- summary(stan_lmer1, pars = "varying"))
+  expect_silent(s <- summary(stan_lmer1, pars = "varying", regex_pars = "Sigma"))
   expect_silent(s_alt <- summary(stan_lmer1, regex_pars = c("plate", "sample")))
   expect_identical(s, s_alt)
   expect_silent(s <- summary(stan_lmer1))
@@ -524,7 +589,7 @@ test_that("print and summary methods ok for mcmc and vb", {
   expect_identical(rownames(s), rownames(d))
 
   expect_silent(s <- summary(example_model, pars = "beta", regex_pars = "herd"))
-  expect_silent(s_alt <- summary(example_model, pars = c("beta", "varying")))
+  expect_silent(s_alt <- summary(example_model, pars = c("beta", "varying"), regex_pars = "Sigma"))
   expect_identical(s, s_alt)
   expect_silent(d <- as.data.frame(s))
   expect_s3_class(s, "summary.stanreg")
@@ -550,6 +615,14 @@ test_that("print and summary methods ok for mcmc and vb", {
   expect_s3_class(s, "summary.stanreg")
   expect_output(print(s), "stan_glm")
   expect_identical(attr(s, "algorithm"), "sampling")
+  
+  # stan_betareg
+  expect_warning(s <- summary(stan_betareg1, pars = "varying"),
+                 regexp = "No group-specific parameters. 'varying' ignored.")
+  expect_silent(s <- summary(stan_betareg1, pars = c("alpha", "beta"), digits = 3))
+  expect_s3_class(s, "summary.stanreg")
+  expect_output(print(s), "stan_betareg")
+  expect_identical(attr(s, "algorithm"), "sampling")
 
   expect_silent(s <- summary(stan_glm_vb1, pars = c("alpha", "beta")))
   expect_silent(d <- as.data.frame(s))
@@ -558,8 +631,6 @@ test_that("print and summary methods ok for mcmc and vb", {
   expect_identical(attr(s, "algorithm"), "meanfield")
 })
 
-
-# print,summary -----------------------------------------------------------
 test_that("print and summary methods ok for optimization", {
   expect_silent(s <- summary(stan_glm_opt1))
   expect_silent(s <- summary(stan_glm_opt1, pars = c("wt", "sigma"), digits = 8))
@@ -574,28 +645,75 @@ test_that("print and summary methods ok for optimization", {
 
   counts <- c(18,17,15,20,10,20,25,13,12)
   outcome <- gl(3,1,9)
-  treatment <- gl(3,3)
-  fit <- stan_glm.nb(counts ~ outcome + treatment, algorithm = "optimizing",
-                     seed = SEED)
-  expect_output(print(fit), "overdispersion")
+  treatment <- gl(3,3)  
+  capture.output(
+    fit <- stan_glm.nb(counts ~ outcome + treatment, algorithm = "optimizing",
+                       seed = SEED)
+  )
+  expect_output(print(fit), "reciprocal_dispersion")
 
   clotting <- data.frame(log_u = log(c(5,10,15,20,30,40,60,80,100)),
                          lot1 = c(118,58,42,35,27,25,21,19,18),
                          lot2 = c(69,35,26,21,18,16,13,12,12))
-  fit2 <- stan_glm(lot1 ~ log_u, data = clotting, family = Gamma(link="log"),
-                   algorithm = "optimizing", seed = SEED)
-  fit3 <- update(fit2, family = inverse.gaussian(link = "log"))
+  capture.output(
+    fit2 <- stan_glm(lot1 ~ log_u, data = clotting, family = Gamma(link="log"),
+                     algorithm = "optimizing", seed = SEED),
+    fit3 <- update(fit2, family = inverse.gaussian(link = "log"))
+  )
   expect_output(print(fit2), "shape")
   expect_output(print(fit3), "lambda")
 })
 
+# prior_summary -----------------------------------------------------------
+test_that("prior_summary errors if info not found", {
+  tmp <- example_model
+  tmp$prior.info <- NULL
+  expect_message(s <- prior_summary(tmp), "Priors not found in stanreg object")
+  expect_null(s)
+})
+test_that("prior_summary doesn't error", {
+  expect_output(print(prior_summary(example_model, digits = 2)),
+                "Priors for model 'example_model'")
+  expect_output(print(prior_summary(stan_lmer1, digits = 2)),
+                "stan_lmer1")
+  expect_output(print(prior_summary(stan_lmer2)),
+                "stan_lmer2")
+  expect_output(print(prior_summary(stan_polr1)),
+                "stan_polr1")
+  expect_output(print(prior_summary(stan_glm_opt1)),
+                "stan_glm_opt1")
+  expect_output(print(prior_summary(stan_glm_vb1)),
+                "stan_glm_vb1")
+  expect_output(print(prior_summary(stan_betareg1)),
+                "stan_betareg1")
+})
+test_that("prior_summary returns correctly named list", {
+  expect_named(prior_summary(example_model),
+               c("prior", "prior_intercept", "prior_covariance"))
+  expect_named(prior_summary(stan_lmer1),
+               c("prior", "prior_intercept", "prior_covariance", "prior_aux"))
+  expect_named(prior_summary(stan_lmer2),
+               c("prior", "prior_intercept", "prior_covariance", "prior_aux"))
+  expect_named(prior_summary(stan_polr1),
+               c("prior", "prior_counts"))
+  expect_named(prior_summary(stan_glm_opt1),
+               c("prior", "prior_intercept", "prior_aux"))
+  expect_named(prior_summary(stan_glm_vb1),
+               c("prior", "prior_intercept", "prior_aux"))
+  expect_named(prior_summary(stan_betareg1),
+               c("prior", "prior_z", "prior_intercept", "prior_intercept_z", "prior_aux"))  
+})
+
 
 # predictive_error,predictive_interval ------------------------------------
+context("predictive error and interval methods")
 test_that("predictive_error works", {
   expect_error(predictive_error(stan_glm1, draws = 100),
                "'draws' should be <= posterior sample size")
   expect_error(predictive_error(stan_polr1),
                "not currently available for stan_polr")
+  expect_error(predictive_error(stan_betareg1, draws = 600),
+               "'draws' should be <= posterior sample size")
   mods <- c("stan_glm1", "stan_glm_vb1", "stan_lmer1",
             "stan_lmer2", "example_model")
   for (m in seq_along(mods)) {
@@ -624,6 +742,10 @@ test_that("predictive_interval works", {
                "'prob' should be a single number greater than 0 and less than 1")
   expect_error(predictive_interval(stan_polr1),
                "not currently available for stan_polr")
+  expect_error(predictive_interval(stan_betareg1, draws = 600),
+               "'draws' should be <= posterior sample size")
+  expect_error(predictive_interval(stan_betareg1, prob = c(0.25, 0.76)),
+               "'prob' should be a single number greater than 0 and less than 1")
   mods <- c("stan_glm1", "stan_glm_vb1", "stan_lmer1",
             "stan_lmer2", "example_model")
   for (m in seq_along(mods)) {
@@ -648,6 +770,11 @@ test_that("predictive_error stanreg and ppd methods return the same thing", {
     predictive_error(stan_glm1, seed = 123),
     predictive_error(preds, y = stan_glm1$y)
   )
+  preds <- posterior_predict(stan_betareg1, seed = 123)
+  expect_equal(
+    predictive_error(stan_betareg1, seed = 123),
+    predictive_error(preds, y = stan_betareg1$y)
+  )
 })
 test_that("predictive_interval stanreg and ppd methods return the same thing", {
   preds <- posterior_predict(stan_glm1, seed = 123)
@@ -655,33 +782,9 @@ test_that("predictive_interval stanreg and ppd methods return the same thing", {
     predictive_interval(stan_glm1, seed = 123),
     predictive_interval(preds)
   )
+  preds <- posterior_predict(stan_betareg1, seed = 123)
+  expect_equal(
+    predictive_interval(stan_betareg1, seed = 123),
+    predictive_interval(preds)
+  )
 })
-
-# prior_summary -----------------------------------------------------------
-test_that("prior_summary doesn't error", {
-  expect_output(print(prior_summary(example_model, digits = 2)),
-                "Priors for model 'example_model'")
-  expect_output(print(prior_summary(stan_lmer1, digits = 2)),
-                "stan_lmer1")
-  expect_output(print(prior_summary(stan_lmer2)),
-                "stan_lmer2")
-  expect_output(print(prior_summary(stan_polr1)),
-                "stan_polr1")
-  expect_output(print(prior_summary(stan_glm_opt1)),
-                "stan_glm_opt1")
-  expect_output(print(prior_summary(stan_glm_vb1)),
-                "stan_glm_vb1")
-})
-test_that("prior_summary returns correctly named list", {
-  expect_named(prior_summary(example_model),
-                c("prior", "prior_intercept", "prior_covariance"))
-  expect_named(prior_summary(stan_lmer1),
-               c("prior", "prior_intercept", "prior_covariance"))
-  expect_named(prior_summary(stan_lmer2),
-               c("prior", "prior_intercept", "prior_covariance"))
-  expect_named(prior_summary(stan_polr1),
-               c("prior", "prior_counts"))
-  expect_named(prior_summary(stan_glm_opt1),
-               c("prior", "prior_intercept"))
-})
-
