@@ -19,6 +19,7 @@
 # package and then running the code below possibly with options(mc.cores = 4).
 
 library(rstanarm)
+library(betareg)
 SEED <- 123
 set.seed(SEED)
 CHAINS <- 2
@@ -47,11 +48,14 @@ test_that("predict ok for binomial", {
   SF <- cbind(numdead, numalive = 20-numdead)
   
   glmfit <- glm(SF ~ sex*ldose, family = binomial)
-  stanfit <- SW(stan_glm(SF ~ sex*ldose, family = binomial, chains = CHAINS, 
-                         iter = ITER, seed = SEED, refresh = REFRESH))
-  stanfit_opt <- SW(stan_glm(SF ~ sex*ldose, family = binomial, 
-                             prior = NULL, prior_intercept = NULL, prior_ops = prior_options(scaled = FALSE),
-                             iter = ITER, seed = SEED, refresh = REFRESH, algorithm = "optimizing"))
+  SW(capture.output(
+    stanfit <- stan_glm(SF ~ sex*ldose, family = binomial, chains = CHAINS, 
+                        iter = ITER, seed = SEED, refresh = REFRESH),
+    stanfit_opt <- stan_glm(SF ~ sex*ldose, family = binomial, 
+                            prior = NULL, prior_intercept = NULL, 
+                            iter = ITER, seed = SEED, refresh = REFRESH, 
+                            algorithm = "optimizing")
+  ))
   
   
   pg <- plink(glmfit)
@@ -79,11 +83,14 @@ test_that("predict ok for binomial", {
 
 test_that("predict ok for gaussian", {
   glmfit <- glm(mpg ~ wt, data = mtcars)
-  stanfit <- SW(stan_glm(mpg ~ wt, data = mtcars, chains = CHAINS,
-                      iter = 2 * ITER, seed = SEED, refresh = REFRESH))
-  stanfit_opt <- SW(stan_glm(mpg ~ wt, data = mtcars,
-                             prior = NULL, prior_intercept = NULL, prior_ops = prior_options(scaled = FALSE),
-                             iter = 2 * ITER, seed = SEED, refresh = REFRESH, algorithm = "optimizing"))
+  SW(capture.output(
+    stanfit <- stan_glm(mpg ~ wt, data = mtcars, chains = CHAINS,
+                        iter = 2 * ITER, seed = SEED, refresh = REFRESH),
+    stanfit_opt <- stan_glm(mpg ~ wt, data = mtcars,
+                            prior = NULL, prior_intercept = NULL,
+                            iter = 2 * ITER, seed = SEED, refresh = REFRESH, 
+                            algorithm = "optimizing")
+  ))
   
   pg <- plink(glmfit)
   ps <- plink(stanfit)
@@ -111,11 +118,12 @@ test_that("predict ok for Poisson", {
                     outcome = gl(3,1,9), treatment = gl(3,3))
 
   glmfit <- glm(counts ~ outcome + treatment, data = dat, family = poisson())
-  stanfit <- SW(stan_glm(counts ~ outcome + treatment, data = dat, family = poisson(), 
-                         chains = CHAINS, iter = ITER, seed = SEED, refresh = REFRESH))
-  stanfit_opt <- SW(stan_glm(counts ~ outcome + treatment, data = dat, family = poisson(), 
-                             iter = ITER, seed = SEED, refresh = REFRESH, algorithm = "optimizing"))
-
+  SW(capture.output(
+    stanfit <- stan_glm(counts ~ outcome + treatment, data = dat, family = poisson(), 
+                        chains = CHAINS, iter = ITER, seed = SEED, refresh = REFRESH),
+    stanfit_opt <- stan_glm(counts ~ outcome + treatment, data = dat, family = poisson(), 
+                            iter = ITER, seed = SEED, refresh = REFRESH, algorithm = "optimizing")
+  ))
   pg <- plink(glmfit)
   ps <- plink(stanfit)
   pso <- plink(stanfit_opt)
@@ -139,3 +147,31 @@ test_that("predict ok for Poisson", {
   expect_equal(pg$se.fit, pso$se.fit, tol = 0.1)
   expect_equal(presp(glmfit, newd)[1:2], presp(stanfit_opt, newd), tol = 0.1)
 })
+
+test_that("predict ok for stan_betareg", {
+  dat <- list()
+  dat$N <- 200
+  dat$x <- rnorm(dat$N, 2, 1)
+  dat$z <- rnorm(dat$N, 2, 1)
+  dat$mu <- binomial(link = "logit")$linkinv(0.5 + 0.2*dat$x)
+  dat$phi <- exp(1.5 + 0.4*dat$z)
+  dat$y <- rbeta(dat$N, dat$mu * dat$phi, (1 - dat$mu) * dat$phi)
+  dat <- data.frame(dat$y, dat$x, dat$z)
+  colnames(dat) <- c("y", "x", "z")
+  
+  betaregfit <- betareg(y ~ x | z, data = dat)
+  SW(capture.output(
+    stanfit <- stan_betareg(y ~ x | z, data = dat, chains = CHAINS,
+                            iter = ITER, seed = SEED, refresh = REFRESH)
+  ))
+  
+  pb <- predict(betaregfit, type = "response")
+  ps <- predict(stanfit, type = "response")
+  expect_equal(pb, ps, tol = 0.05)
+  expect_error(presp(stanfit))
+  
+  newd <- data.frame(x = c(300,305))
+  pb <- predict(betaregfit, newdata = newd, type = "link")
+  ps <- predict(stanfit, newdata = newd, type = "link")
+  expect_equal(pb, ps, tol = 0.05)
+})
